@@ -54,15 +54,13 @@ class GitProject:
         config = configparser.ConfigParser()
         config.read(config_path)
         base_url = config.get('remote "origin"', "url")
-        url = base_url.replace("git@", '').replace(":", "/")
-        url = 'http://' + url if "http" not in url else url
+        url = base_url.split("@", maxsplit=1)[-1] if '@' in base_url else base_url
+        url = 'http://' + url.replace(":", "/") if "http" not in url else url.replace(":", "/")
         parse = urlparse(url)
-        print(parse)
         return parse
 
     @staticmethod
     def git_host():
-        print(GitProject.git_url_parse().hostname)
         return GitProject.git_url_parse().hostname
 
     @staticmethod
